@@ -216,22 +216,22 @@ def open_path(quteproc, server, path):
 
     while True:
         if path.endswith(new_tab_suffix):
-            path = path[:-len(new_tab_suffix)]
+            path = path.removesuffix(new_tab_suffix)
             new_tab = True
         elif path.endswith(new_bg_tab_suffix):
-            path = path[:-len(new_bg_tab_suffix)]
+            path = path.removesuffix(new_bg_tab_suffix)
             new_bg_tab = True
         elif path.endswith(new_window_suffix):
-            path = path[:-len(new_window_suffix)]
+            path = path.removesuffix(new_window_suffix)
             new_window = True
         elif path.endswith(private_suffix):
-            path = path[:-len(private_suffix)]
+            path = path.removesuffix(private_suffix)
             private = True
         elif path.endswith(as_url_suffix):
-            path = path[:-len(as_url_suffix)]
+            path = path.removesuffix(as_url_suffix)
             as_url = True
         elif path.endswith(do_not_wait_suffix):
-            path = path[:-len(do_not_wait_suffix)]
+            path = path.removesuffix(do_not_wait_suffix)
             wait = False
         else:
             break
@@ -264,7 +264,7 @@ def run_command(quteproc, server, tmpdir, command):
 
     invalid_tag = ' (invalid command)'
     if command.endswith(invalid_tag):
-        command = command[:-len(invalid_tag)]
+        command = command.removesuffix(invalid_tag)
         invalid = True
     else:
         invalid = False
@@ -273,16 +273,18 @@ def run_command(quteproc, server, tmpdir, command):
     command = testutils.substitute_testdata(command)
     command = command.replace('(tmpdir)', str(tmpdir))
     command = command.replace('(dirsep)', os.sep)
+    command = command.replace('(rootpath)', 'C:\\' if utils.is_windows else '/')
     command = command.replace('(echo-exe)', _get_echo_exe_path())
 
     quteproc.send_cmd(command, count=count, invalid=invalid)
 
 
-@bdd.when(bdd.parsers.parse("I reload"))
-def reload(qtbot, server, quteproc):
+@bdd.when(bdd.parsers.parse("I reload {path}"))
+def reload(qtbot, server, quteproc, path):
     """Reload and wait until a new request is received."""
     with qtbot.wait_signal(server.new_request):
         quteproc.send_cmd(':reload')
+        quteproc.wait_for_load_finished(path)
 
 
 @bdd.when(bdd.parsers.parse("I wait until {path} is loaded"))
@@ -350,10 +352,9 @@ def fill_clipboard(quteproc, server, what, content):
 
 
 @bdd.when(bdd.parsers.re(r'I put the following lines into the '
-                         r'(?P<what>primary selection|clipboard):\n'
-                         r'(?P<content>.+)$', flags=re.DOTALL))
-def fill_clipboard_multiline(quteproc, server, what, content):
-    fill_clipboard(quteproc, server, what, textwrap.dedent(content))
+                         r'(?P<what>primary selection|clipboard):', flags=re.DOTALL))
+def fill_clipboard_multiline(quteproc, server, what, docstring):
+    fill_clipboard(quteproc, server, what, textwrap.dedent(docstring))
 
 
 @bdd.when(bdd.parsers.parse('I hint with args "{args}"'))
@@ -456,20 +457,20 @@ def path_should_be_requested(server, path):
     server.wait_for(verb='GET', path='/' + path)
 
 
-@bdd.then(bdd.parsers.parse("The requests should be:\n{pages}"))
-def list_of_requests(server, pages):
+@bdd.then(bdd.parsers.parse("The requests should be:"))
+def list_of_requests(server, docstring):
     """Make sure the given requests were done from the webserver."""
     expected_requests = [server.ExpectedRequest('GET', '/' + path.strip())
-                         for path in pages.split('\n')]
+                         for path in docstring.split('\n')]
     actual_requests = server.get_requests()
     assert actual_requests == expected_requests
 
 
-@bdd.then(bdd.parsers.parse("The unordered requests should be:\n{pages}"))
-def list_of_requests_unordered(server, pages):
+@bdd.then(bdd.parsers.parse("The unordered requests should be:"))
+def list_of_requests_unordered(server, docstring):
     """Make sure the given requests were done (in no particular order)."""
     expected_requests = [server.ExpectedRequest('GET', '/' + path.strip())
-                         for path in pages.split('\n')]
+                         for path in docstring.split('\n')]
     actual_requests = server.get_requests()
     # Requests are not hashable, we need to convert to ExpectedRequests
     actual_requests = [server.ExpectedRequest.from_request(req)
@@ -533,21 +534,21 @@ def javascript_message_not_logged(quteproc, message):
                                message='[*] {}'.format(message))
 
 
-@bdd.then(bdd.parsers.parse("The session should look like:\n{expected}"))
-def compare_session(quteproc, expected):
+@bdd.then(bdd.parsers.parse("The session should look like:"))
+def compare_session(quteproc, docstring):
     """Compare the current sessions against the given template.
 
     partial_compare is used, which means only the keys/values listed will be
     compared.
     """
-    quteproc.compare_session(expected)
+    quteproc.compare_session(docstring)
 
 
 @bdd.then(
-    bdd.parsers.parse("The session saved with {flags} should look like:\n{expected}"))
-def compare_session_flags(quteproc, flags, expected):
+    bdd.parsers.parse("The session saved with {flags} should look like:"))
+def compare_session_flags(quteproc, flags, docstring):
     """Compare the current session saved with custom flags."""
-    quteproc.compare_session(expected, flags=flags)
+    quteproc.compare_session(docstring, flags=flags)
 
 
 @bdd.then("no crash should happen")
@@ -600,17 +601,17 @@ def check_not_contents_plain(quteproc, text):
     assert text not in content
 
 
-@bdd.then(bdd.parsers.parse('the json on the page should be:\n{text}'))
-def check_contents_json(quteproc, text):
+@bdd.then(bdd.parsers.parse('the json on the page should be:'))
+def check_contents_json(quteproc, docstring):
     """Check the current page's content as json."""
     content = quteproc.get_content().strip()
-    expected = json.loads(text)
+    expected = json.loads(docstring)
     actual = json.loads(content)
     assert actual == expected
 
 
-@bdd.then(bdd.parsers.parse("the following tabs should be open:\n{tabs}"))
-def check_open_tabs(quteproc, request, tabs):
+@bdd.then(bdd.parsers.parse("the following tabs should be open:"))
+def check_open_tabs(quteproc, docstring):
     """Check the list of open tabs in the session.
 
     This is a lightweight alternative for "The session should look like: ...".
@@ -620,7 +621,7 @@ def check_open_tabs(quteproc, request, tabs):
     session = quteproc.get_session()
     active_suffix = ' (active)'
     pinned_suffix = ' (pinned)'
-    tabs = tabs.splitlines()
+    tabs = docstring.splitlines()
     assert len(session['windows']) == 1
     assert len(session['windows'][0]['tabs']) == len(tabs)
 
@@ -639,11 +640,11 @@ def check_open_tabs(quteproc, request, tabs):
         while line.endswith(active_suffix) or line.endswith(pinned_suffix):
             if line.endswith(active_suffix):
                 # active
-                line = line[:-len(active_suffix)]
+                line = line.removesuffix(active_suffix)
                 active = True
             else:
                 # pinned
-                line = line[:-len(pinned_suffix)]
+                line = line.removesuffix(pinned_suffix)
                 pinned = True
 
         session_tab = session['windows'][0]['tabs'][i]
@@ -670,9 +671,9 @@ def clipboard_contains(quteproc, server, what, content):
         what, json.dumps(expected)))
 
 
-@bdd.then(bdd.parsers.parse('the clipboard should contain:\n{content}'))
-def clipboard_contains_multiline(quteproc, server, content):
-    expected = textwrap.dedent(content).replace('(port)', str(server.port))
+@bdd.then(bdd.parsers.parse('the clipboard should contain:'))
+def clipboard_contains_multiline(quteproc, server, docstring):
+    expected = textwrap.dedent(docstring).replace('(port)', str(server.port))
     quteproc.wait_for(message='Setting fake clipboard: {}'.format(
         json.dumps(expected)))
 
@@ -739,7 +740,7 @@ def set_up_fileselector(quteproc, py_proc, tmpdir, kind, files, output_type):
         tmp_file = None
         for i, arg in enumerate(sys.argv):
             if arg.startswith('--file='):
-                tmp_file = arg[len('--file='):]
+                tmp_file = arg.removeprefix('--file=')
                 sys.argv.pop(i)
                 break
         selected_files = sys.argv[1:]
